Installation
============

Install from PyPi
-----------------
MAX-BLE-HCI is hosted via PyPi and can be installed with the following command
.. code-block:: bash

    pip install max-ble-hci

Installation from Source
------------------------
If you prefer to use the most up to date version, you can also install from source.

The intsall.sh or .bat are used to install the library into your Python site packages and be done as such.

| On Linux or MacOS

.. code-block:: bash

    sudo chmod +x install.sh
    ./install.sh
    
| On Windows

.. code-block:: bash
    
    install.bat

